package samples.transferAgent;
import java.util.ArrayList;
import java.util.List;

import unlimited.fc.rest.transferagent.model.TransferConfigurationModel;
import unlimited.fc.rest.transferagent.model.TransferFilesRequestModel;

/**
 * Small download sample that runs two downloads with TransferAgent. The first is download of a folder and file with the basic
 * transfer setting. The second is a download of the folder/files with some transfer configurations set.
 * 
 * Sample prerequisite:
 *    --- Update the Server connection settings in TransferAgentSampleConstants.java to point to the Server you wish to connect to
 *    --- Update FILE_TO_DOWNLOAD with a valid remote file path on the Server
 *    --- Update FOLDER_TO_DOWNLOAD with a valid remote file path on the Server
 *    --- Update DOWNLOAD_LOCATION with a valid local file path where the download can be sored
 */
public class TADownloadSample extends TASampleBase {
  
  private final static String FOLDER_TO_DOWNLOAD = "TestFolder/";
  private final static String FILE_TO_DOWNLOAD = "testFile.txt";
  private final static String DOWNLOAD_LOCATION = "C:/temp/downloadExample";
  
  public TADownloadSample() {
    super();
  }

  /**
   * This method is a sample of how you can use the TransferAgent to download files/folders to the Server. The method does this by
   * connecting the TransferAgent to a remote Server, constructing a TransferRequest, and then executing an DownloadTransferRequest
   * @throws Exception
   */
  public void performDownload() throws Exception {
    String connectionKey = generateConnectionKey(SERVER_IP, SERVER_PORT_STR, SERVER_USERNAME, SERVER_PASSWORD);
    System.out.println("TransferAgent successfully connected");
    
    final List<String> downloadFiles = new ArrayList<>();
    downloadFiles.add(FOLDER_TO_DOWNLOAD);
    downloadFiles.add(FILE_TO_DOWNLOAD);
    
    TransferFilesRequestModel transferRequest = getTransferFilesModel(connectionKey, "local");
    transferRequest.setFileList(downloadFiles);
    transferRequest.setLocalWorkingDirectory(DOWNLOAD_LOCATION);
    System.out.println("Download transfer request generated. Submitting request to TA");
    
    performTAFileTransfer(transferRequest);
    System.out.println("\nTransfer has completed successfully");
  }
  
  /**
   * This method is a sample of how you can use the TransferAgent to download files/folders to the Server. The method does this by
   * connecting the TransferAgent to a remote Server, constructing a TransferRequest, and then executing an DownloadTransferRequest
   * @throws Exception
   */
  public void performDownloadWithTransferConfigurations() throws Exception {
    String connectionKey = generateConnectionKey(SERVER_IP, SERVER_PORT_STR, SERVER_USERNAME, SERVER_PASSWORD);
    System.out.println("TransferAgent successfully connected");
    
    final List<String> downloadFiles = new ArrayList<>();
    downloadFiles.add(FOLDER_TO_DOWNLOAD);
    downloadFiles.add(FILE_TO_DOWNLOAD);
    
    TransferConfigurationModel transferConfig = new TransferConfigurationModel();
    transferConfig.setUseIncremental(false);
    transferConfig.setAutoResume(false);
    
    TransferFilesRequestModel transferRequest = getTransferFilesModel(connectionKey, "local");
    transferRequest.setFileList(downloadFiles);
    transferRequest.setLocalWorkingDirectory(DOWNLOAD_LOCATION);
    transferRequest.setTransferConfiguration(transferConfig);
    System.out.println("Download transfer request generated. Submitting request to TA");
    
    performTAFileTransfer(transferRequest);
    System.out.println("\nTransfer has completed successfully");
  }
  
  public static void main(String[] args) throws Exception {
    TADownloadSample sample = new TADownloadSample();
    sample.performDownload();
    sample.performDownloadWithTransferConfigurations();
    
    System.out.println("Sample has completed");
  }
}
