package samples.transferAgent;
import javax.ws.rs.core.Response.Status;

import unlimited.fc.rest.shared.model.FileObjectsModel;

/**
 * Sample resource that performs standard file listing operations for both the local and remote
 * file systems.
 * 
 * Sample prerequisite:
 *    --- Update the Server connection settings in TransferAgentSampleConstants.java to point to the Server you wish to connect to
 */
public class TAListingAPISample extends TASampleBase {
  
  public TAListingAPISample() {
    super();
  }
  
  /**
   * Performs a standard listing of the FileSystem roots available to the TransferAgent, and a listing of the
   * current working directory
   * @throws Exception 
   */
  public void performLocalFileListingExample() throws Exception {
    String rootLocalFilePath = getRESTURLForPath(LOCAL_PATH);
    System.out.println("\nRunning local file listing sample");
    
    // Root directory listing
    final FileObjectsModel rootFileData = restEvoker.doGETCall(rootLocalFilePath, FileObjectsModel.class, Status.OK);
    outputFileListData(rootFileData);
    
    // Current working dir listing
    final String workingDir = normalizeFilePath(System.getProperty("user.dir"));
    final String workingDirRESTPath = getRESTURLForPath(LOCAL_PATH + "/" + workingDir);
    final FileObjectsModel workingDirFileData = restEvoker.doGETCall(workingDirRESTPath, FileObjectsModel.class, Status.OK);
    outputFileListData(workingDirFileData);
  }
  
  /**
   * Normalizes a provided file path by replacing the slashes (\) with stanard unix slashes (/)
   * @param path Path of the file to normalize
   * @return String containing the normalized path
   */
  private String normalizeFilePath(String path) {
    return path.replace("\\\\", "\\").replace("\\", "/");
  }
  
  /**
   * Performs a standard listing of the remote files present on the connected Server
   * @throws Exception
   */
  public void performRemoteFileListingExample() throws Exception {
    System.out.println("\nRunning remote file listing sample");
    String connectionKey = generateConnectionKey(SERVER_IP, SERVER_PORT_STR, SERVER_USERNAME, SERVER_PASSWORD);
    
    String remoteFileRESTPath = getRESTURLForPath(REMOTE_PATH);
    restEvoker.addQueryParam("connectionKey", connectionKey);
    
    final FileObjectsModel remoteFileData = restEvoker.doGETCall(remoteFileRESTPath, FileObjectsModel.class, Status.OK);
    outputFileListData(remoteFileData);
  }

  public static void main(String[] args) throws Exception {
    TAListingAPISample sample = new TAListingAPISample();
    sample.performLocalFileListingExample();
    sample.performRemoteFileListingExample();
    
    System.out.println("Sample has completed");
  }
}
