package samples.transferAgent;
import java.util.Arrays;
import java.util.List;

import unlimited.fc.client.transferagent.transfermanager.TATransferSelections;
import unlimited.fc.rest.transferagent.model.TransferConfigurationModel;
import unlimited.fc.rest.transferagent.model.TransferFilesRequestModel;

/**
 * Small example that uploads a singular file to the Server. Sample performs the Transfer with default transfer settings,
 * and once again with different transfer configurations 
 * 
 * Sample prerequisite:
 *    --- Update the Server connection settings in TransferAgentSampleConstants.java to point to the Server you wish to connect to
 *    --- Update LOCAL_UPLOAD_FILE with a valid remote file path on the Server
 */
public class TAUploadTransferSample extends TASampleBase {

  private final static String LOCAL_UPLOAD_FILE = "C:\\temp\\testFile.txt";
  
  public TAUploadTransferSample() {
    super();
  }

  /**
   * This method is a sample of how you can use the TransferAgent to upload a file to the Server. The method does this by
   * connecting the TransferAgent to a remote Server, constructing a TransferRequest, and then executing an UploadTransferRequest
   * @throws Exception
   */
  public void simpleUploadFile() throws Exception {
    System.out.println("\nBeginning TransferAgent Upload with default settings");
    
    String connectionKey = generateConnectionKey(SERVER_IP, SERVER_PORT_STR, SERVER_USERNAME, SERVER_PASSWORD);
    System.out.println("TransferAgent successfully connected");
    
    final List<String> uploadFiles = Arrays.asList(LOCAL_UPLOAD_FILE);
    TransferFilesRequestModel transferRequest = getTransferFilesModel("local", connectionKey);
    transferRequest.setFileList(uploadFiles);
    System.out.println("Upload transfer request generated. Submitting request to TA");
    
    performTAFileTransfer(transferRequest);
    System.out.println("\nTransfer has completed successfully");
  }

  /**
   * This method uploads a file to the Server, with different transfer configurations.
   * @throws Exception
   */
  public void simpleUploadWithTransferConfigurations() throws Exception {
    System.out.println("\nBeginning TransferAgent Upload with configuration example");
    
    String connectionKey = generateConnectionKey(SERVER_IP, SERVER_PORT_STR, SERVER_USERNAME, SERVER_PASSWORD);
    System.out.println("TransferAgent successfully connected");

    // Specify transfer configuration to be used within the Transfer
    TransferConfigurationModel transferConfig = new TransferConfigurationModel();
    transferConfig.setAutoResume(true);
    transferConfig.setUseIncremental(true);
    transferConfig.setOverwriteOption(TATransferSelections.YES_TO_ALL);
    transferConfig.setResumeOption(TATransferSelections.YES_TO_ALL);
    transferConfig.setProgressiveTransfers(true);
    System.out.println("Transfer configuration generated");
    
    final List<String> uploadFiles = Arrays.asList(LOCAL_UPLOAD_FILE);
    TransferFilesRequestModel transferRequest = getTransferFilesModel("local", connectionKey);
    transferRequest.setFileList(uploadFiles);
    transferRequest.setTransferConfiguration(transferConfig);
    
    System.out.println("Upload transfer request generated. Submitting request to TA");
    
    performTAFileTransfer(transferRequest);
    System.out.println("\nTransfer has completed successfully");
  }

  public static void main(String[] args) throws Exception {
    TAUploadTransferSample sample = new TAUploadTransferSample();
    sample.simpleUploadFile();
    sample.simpleUploadWithTransferConfigurations();
    
    System.out.println("Sample has completed");
  }
}
