package samples.transferAgentViaCentral;
import java.util.Arrays;
import java.util.List;

import javax.ws.rs.core.Response.Status;

import samples.SampleConstants;
import unlimited.fc.rest.shared.model.FileObjectsModel;
import unlimited.fc.rest.transferagent.model.TransferFilesRequestModel;

/**
 * This sample resource performs standard TransferAgent use cases (local/remote file listings, basic upload transfers) 
 * through the Central REST proxy. 
 * 
 * Sample prerequisite:
 *    --- Connect the TransferAgent application a FileCatalystCentral instance
 *    --- Update the Central connection settings in {@link TAViaCentralConstants} to point to the Central instance  
 *    --- Update the Server connection settings in {@link SampleConstants} to point to the Server you wish to connect to
 *    --- Update FILE_PATH_TO_UPLOAD to point to a local file residing on the TransferAgent's file system
 */
public class TAViaCentralBasicSample extends TAViaCentralSampleBase {

  private final static String FILE_PATH_TO_UPLOAD = "C:/consoleText.txt"; 
  
  public TAViaCentralBasicSample () throws Exception {
    super();
  }

  /**
   * Uses the Central REST Proxy to perform a file listing of the TransferAgent's local file system
   * @throws Exception Thrown if there is a problem communicating with the TransferAgent node
   */
  public void performTAviaCentralLocalFileList() throws Exception {
    System.out.println("\nPerforming TransferAgent local file listing through Central sample");
    
    String localRESTPath = getRESTURLForPath(LOCAL_PATH);
    final FileObjectsModel localFileData = restEvoker.doGETCall(localRESTPath, FileObjectsModel.class, Status.OK);
    outputFileListData(localFileData);
  }
  
  /**
   * Uses the Central REST Proxy to perform a remote file listing of the Server that the TransferAgent is connect to
   * @throws Exception Thrown if there is a problem communicating with the TransferAgent node
   */
  public void performTAviaCentralRemoteFileList() throws Exception {
    System.out.println("\nPerforming TransferAgent remote file listing through Central sample");
    final String connectionKey = generateConnectionKey(SERVER_IP, SERVER_PORT_STR, SERVER_USERNAME, SERVER_PASSWORD);

    String remoteFilePath = getRESTURLForPath(REMOTE_PATH);
    restEvoker.addQueryParam("connectionKey", connectionKey);
    
    final FileObjectsModel localFileData = restEvoker.doGETCall(remoteFilePath, FileObjectsModel.class, Status.OK);
    outputFileListData(localFileData);
  }
  
  /**
   * Uses the Central REST proxy to perform a remote upload transfer from the TransferAgent's local file system
   * to the configured Server connection 
   * @throws Exception  Thrown if one of the REST services returns with an invalid status code
   */
  public void performTAviaCentralUploadTransferSample() throws Exception {
    final String connectionKey = generateConnectionKey(SERVER_IP, SERVER_PORT_STR, SERVER_USERNAME, SERVER_PASSWORD);
    
    final TransferFilesRequestModel uploadTransferRequest = getTransferFilesModel("local", connectionKey);
    final List<String> uploadFileList = Arrays.asList(FILE_PATH_TO_UPLOAD);
    uploadTransferRequest.setFileList(uploadFileList);
    
    performTAFileTransfer(uploadTransferRequest);
  }
 
  public static void main(String[] args) throws Exception {
    TAViaCentralBasicSample sampleApp = new TAViaCentralBasicSample();
    sampleApp.performTAviaCentralLocalFileList();
    sampleApp.performTAviaCentralRemoteFileList();
    sampleApp.performTAviaCentralUploadTransferSample();
  }  
}
